@@ -17,16 +17,16 @@
     *************************************************************************
 */
 
+#include "autotestbase.h"
+
 #include <QTest>
 #include <QDir>
 #include <QFile>
 #include <QStandardPaths>
-#include <QTextStream>
-#include <QDebug>
 
 #include <kemoticons.h>
 
-static const char * default_theme = "Glass";
+static const char * default_theme = "__woopwoop__";
 
 /*
   There are three sets of tests, the Kopete 0.7 baseline with tests that were
@@ -42,41 +42,17 @@ class KEmoticonTest : public QObject
 {
     Q_OBJECT
 
-private:
-    bool copyTheme(const QString &dir, const QDir &baseThemeDir, const QString &themeName)
-    {
-        QDir sourceThemeDir(dir);
-        if (!sourceThemeDir.exists()) {
-            return false;
-        }
-        QDir themeDir(baseThemeDir.absolutePath() + '/' + themeName);
-        themeDir.removeRecursively();
-        themeDir.mkpath(QStringLiteral("."));
-
-        foreach (const QString &fileName, sourceThemeDir.entryList(QDir::Files)) {
-            if (!QFile::copy(sourceThemeDir.filePath(fileName),
-                                themeDir.filePath(fileName))) {
-                qWarning() << "couldn't copy" << dir << "/" << fileName;
-                return false;
-            }
-        }
-        return true;
-    }
-
 private Q_SLOTS:
     void initTestCase()
     {
         QStandardPaths::setTestModeEnabled(true);
+        cleanupTestCase();
+
         QString dataPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-
         QString destThemePath = dataPath + QLatin1String("/emoticons/");
+        QVERIFY(QDir().mkpath(destThemePath));
         QDir themeDir(destThemePath);
-        if (themeDir.exists()) {
-            QVERIFY(themeDir.removeRecursively());
-        }
-        QVERIFY(themeDir.mkpath(QStringLiteral(".")));
-
-        QVERIFY(copyTheme(QFile::decodeName(LOCAL_THEMES_DIR) + QLatin1String("/") + default_theme, themeDir, default_theme));
+        QVERIFY(copyTheme(QFINDTESTDATA("default-testtheme"), themeDir, QString::fromLatin1(default_theme)));
 
         // check it can actually be found
         themePath = QStandardPaths::locate(
@@ -84,6 +60,7 @@ private Q_SLOTS:
                 QStringLiteral("emoticons/"),
                 QStandardPaths::LocateDirectory);
         QVERIFY2(!themePath.isEmpty(), qPrintable(themePath));
+        QCOMPARE(themePath, destThemePath);
 
         // also copy the xmpp theme
         QVERIFY(copyTheme(QFINDTESTDATA("xmpp-testtheme"), themeDir, QStringLiteral("xmpp-testtheme")));
@@ -93,8 +70,8 @@ private Q_SLOTS:
     {
         QString dataPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
         const QString themePath = dataPath + QLatin1String("/emoticons/");
-        QDir themeDir(themePath);
-        QVERIFY(themeDir.removeRecursively());
+        QVERIFY(QDir(themePath + QString::fromLatin1(default_theme)).removeRecursively());
+        QVERIFY(QDir(themePath + QStringLiteral("xmpp-testtheme")).removeRecursively());
     }
 
     void testEmoticonParser_data()
@@ -108,15 +85,15 @@ private Q_SLOTS:
         QVERIFY(!basePath.isEmpty());
         QDir testCasesDir(basePath);
 
-        QStringList inputFileNames = testCasesDir.entryList(QStringList(QStringLiteral("*.input")));
-        Q_FOREACH (const QString &fileName, inputFileNames) {
+        const QStringList inputFileNames = testCasesDir.entryList(QStringList(QStringLiteral("*.input")));
+        for (const QString &fileName : inputFileNames) {
             QString outputFileName = fileName;
             outputFileName.replace(QStringLiteral("input"), QStringLiteral("output"));
             const QString baseName = fileName.section(QLatin1Char('-'), 0, 0);
-            QTest::newRow(qPrintable(fileName.left(fileName.lastIndexOf('.'))))
+            QTest::newRow(qPrintable(fileName.left(fileName.lastIndexOf(QLatin1Char('.')))))
                 << basePath + QLatin1Char('/') + fileName
                 << basePath + QLatin1Char('/') + outputFileName
-                << (baseName == QLatin1String("xmpp") ? "xmpp-testtheme" : default_theme)
+                << (baseName == QLatin1String("xmpp") ? QStringLiteral("xmpp-testtheme") : QString::fromLatin1(default_theme))
                 << (baseName == QLatin1String("broken"));
         }
     }
@@ -143,7 +120,7 @@ private Q_SLOTS:
 
             QString result = emo.parseEmoticons(inputData,
                     KEmoticonsTheme::RelaxedParse | KEmoticonsTheme::SkipHTML);
-            result.replace(themePath + themeName + '/', QString());
+            result.remove(QStringLiteral("file://") + themePath + themeName + QLatin1Char('/'));
 
             if (xfail) {
                 QEXPECT_FAIL("", "Checking known-broken testcase", Continue);
@@ -164,13 +141,13 @@ private Q_SLOTS:
         QVERIFY(!basePath.isEmpty());
         QDir testCasesDir(basePath);
 
-        QStringList inputFileNames = testCasesDir.entryList(QStringList(QStringLiteral("*.input")));
-        Q_FOREACH (const QString &fileName, inputFileNames) {
+        const QStringList inputFileNames = testCasesDir.entryList(QStringList(QStringLiteral("*.input")));
+        for (const QString &fileName : inputFileNames) {
             QString outputFileName = fileName;
             outputFileName.replace(QStringLiteral("input"), QStringLiteral("output"));
             const QString baseName = fileName.section(QLatin1Char('-'), 0, 0);
-            QTest::newRow(qPrintable(fileName.left(fileName.lastIndexOf('.'))))
-            << (baseName == QLatin1String("xmpp") ? "xmpp-testtheme" : default_theme);
+            QTest::newRow(qPrintable(fileName.left(fileName.lastIndexOf(QLatin1Char('.')))))
+            << (baseName == QLatin1String("xmpp") ? QStringLiteral("xmpp-testtheme") : QString::fromLatin1(default_theme));
         }
     }
 
@@ -182,10 +159,10 @@ private Q_SLOTS:
 
         KEmoticonsTheme theme = kemoticons.theme(themeName);
 
-        const QString parsed = theme.parseEmoticons(":)");
+        const QString parsed = theme.parseEmoticons(QStringLiteral(":)"));
 
-        QVERIFY(parsed.contains(QStringLiteral("width=\"99\"")));
-        QVERIFY(parsed.contains(QStringLiteral("height=\"77\"")));
+        QVERIFY(parsed.contains(QLatin1String("width=\"99\"")));
+        QVERIFY(parsed.contains(QLatin1String("height=\"77\"")));
     }
 
 private:
